############################################################
#                                                          #
#                 targetting.py                            #
#                                                          #
#                  Blender 2.54                            #
#                                                          #
#   Author Irvine on  http://blenderartists.org/forum/     #
#                                                          #
#         Use as you wish, but give me credit              #
#                                                          #
############################################################

# This is one of four scripts that control bullets, this script
# orientates the bullet with the weapons reticule. Important, else
# bullet aiming is not accurate!


# Setting things up
# get the bge.logic module
import bge
#import mathutils as math
from mathutils import Vector  as Vec



# set things up
controller = bge.logic.getCurrentController()
pilot=controller.owner

# retrieve the active camera variable from the global dictionary
camera = bge.logic.globalDict["active_camera"]

# retrieve the targetting boolean, this is to avoid stupid warnings
targetting = bge.logic.globalDict["targetting"]

# retrieve the dead_pilot boolean
dead_pilot = bge.logic.globalDict["dead_pilot"]

# retrieve the bullet "speed" from global dictionary
bullet_speed = bge.logic.globalDict["bullet_speed"]


# some constants
targ_X = 2.0
targ_Z = 3.30
cor_Y = 19

#####


# assign target sensor
target = controller.sensors["target_distance"]

# get the target position as modulus
target_position = Vec(target.hitPosition) 
target_modulus = target_position.length


# in case we are targetting empty space
if target_modulus != 0:
    # yes, we have a target
    targ_dist = target_position - pilot.worldPosition
    targ_Y  = -targ_dist.length + cor_Y
else:
    # no, we are targetting empty space
    targ_Y = -target.range + cor_Y
    
    
target_vec_left = Vec([-targ_X,targ_Y,targ_Z]) 
target_vec_right = Vec([targ_X,targ_Y,targ_Z])



# turn it into a velocity
velocity_bullet_left = Vec.normalize(target_vec_left)*bullet_speed
velocity_bullet_right = Vec.normalize(target_vec_right)*bullet_speed



####

# activate/deactivate the "target aquired" overlay
# is the "pilot" the active camera?
if camera == "pilot":
    # yes, "pilot" is the active camera
    # is there a target in range?
    if target_modulus != 0:
        # yes, target in range
        # avoid stupid warning messages
        if not targetting and not dead_pilot:
            # add targetting reticule to HUD and set targetting flag
            controller.activate("add_targetting")
            targetting = True
    else:
        # no, target not in range
        # avoid stupid warning messages
        if targetting:
            # remove targetting reticule from HUD and re-set targetting flag
            controller.activate("remove_targetting")
            targetting = False
else:
    # no "pilot" is not the active camera
    # avoid stupid warning messages
    if targetting:
        # remove targetting reticule from HUD and re-set targetting flag
        controller.activate("remove_targetting")
        targetting = False


# save the targetting boolean       
bge.logic.globalDict["targetting"] = targetting

# save the velocity vectors
bge.logic.globalDict["velocity_bullet_left"] = velocity_bullet_left
bge.logic.globalDict["velocity_bullet_right"] = velocity_bullet_right


#End script